InductiveDataset
================

.. currentmodule:: pykeen.datasets.inductive

.. autoclass:: InductiveDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InductiveDataset.create_inverse_triples
      ~InductiveDataset.inductive_validation

   .. rubric:: Methods Summary

   .. autosummary::

      ~InductiveDataset.summarize
      ~InductiveDataset.summary_str

   .. rubric:: Attributes Documentation

   .. autoattribute:: create_inverse_triples
   .. autoattribute:: inductive_validation

   .. rubric:: Methods Documentation

   .. automethod:: summarize
   .. automethod:: summary_str
